def 轉譯議會備詢提問(原始內容): 
    return f'''在台灣，請用繁體中文回答。以下我將提供審計部臺灣省宜蘭縣審計室對於追蹤查核意見後續改善情形後，所辦理的3則議會備詢標題與架構內容給您參考。

        第1則 
        標題：易肇事路口改善及通勤月票方案研擬情形（乙-31）
        內容：
(一) 審核情形
截至112年3月底止，已完成51處易肇事路口改善，剩餘12處路口預計於112年底完成改善。經查其執行情形，核有：
1.	已完成改善之51處路口，其中有5處路口已分別於109年12月、110年1月及110年4月完成改善，惟仍名列道安資訊查詢網111年度宜蘭縣前10大肇事熱點排行第1、2、4、6及7位，且上述路口近3年度肇事件數及受傷人數多數呈現逐年增加趨勢，顯示易肇事路口改善成效未如預期。
2.	行政院所訂111年度「30日交通事故死亡人數」目標，為較110年度減少至少5％。宜蘭縣111年度「30日交通事故死亡人數」為87人，雖較110年度死亡100人，減少13人（13％），惟111年度每10萬人死亡人數19.4人，仍為全國第7高，受傷人數11,029人，較110年度10,404人，增加625人，每10萬人受傷人數2,456.7人為全國第8高，111年度交通事故總件數8,367件，亦較110年度7,865件，增加502件（6.38％）。經縣政府分析肇事原因，死亡事故主要發生於村里道路，以未注意車前狀況占30％最多，受傷事故主要發生於巿區道路，以未依規定讓車占20.4％最多。
3.	交通部於111年10月7日函為辦理無號誌路口設置「停」標字（誌）設施改善計畫專案，請各縣巿道路安全聯席會報於111年12月31日前優先完成盤點，108至110年發生A1（造成人員當場或24小時內死亡之交通事故）及A2（造成人員受傷或超過24小時死亡之交通事故）交通事故之轄管道路（省道除外）支道未劃設「停」或「讓」標誌（線）之無號誌路口地點與數量，並於112年6月30日前完成支道劃設「停」標字（誌）設施。縣政府於111年10月24日函請各鄉鎮巿公所及交通處於112年5月31日前辦理完竣，並自111年12月起每月函送辦理情形。截至112年4月底止，各路權機關（單位）已完成盤點作業，108至110年發生A1及A2交通事故之無號誌路口地點共計350處，已完成改善254處，完成改善比率72.57％，尚有96處、27.43％尚未完成改善，包括蘇澳鎮公所3處路口及交通處93處路口尚待完成改善，惟距縣政府所訂完成期限即將屆滿。
4.	公路總局為評估「行政院促進公共運輸使用方案」通勤月票措施預算，於112年2月14日函請各縣巿政府於112年2月17日中午前先行提供概估通勤月票方案所需經費。嗣縣政府蒐集相關巿區公車與國道客運之運量資料，經概估「北宜生活圈通勤月票」（配合基北北桃宜月票加價購）票價為1,980元，搭乘國道客運通勤人數7,200人/日，每月縣政府負擔296萬餘元，中央補助2,669萬餘元；宜蘭縣公共運輸月票（單一月票）票價為1,250元，搭乘火車通勤人數5,800人/日，巿區公車5,200人/日，每月縣政府負擔208萬餘元，中央補助659萬餘元等資料予公路總局，惟查縣政府迄112年5月始確認月票方案內容及提出申請。為達減輕縣民通勤（學）交通負擔及提升公共運輸運量之目的，經函請縣政府儘速研擬通勤月票方案，並注意路線及班次便利性，以增加使用誘因，妥為預估年度運量績效目標，避免因未達年度目標而遭折減補助款。
(二)機關改善情形
1.	交通處將邀集各相關單位共同研商分析該 5 處肇事熱點之癥結原因，並研擬改善精進作為。
2.	有關「未注意車前狀況」及「未依規定讓車」交通事故防制對策包括：（1）檢討路口上游約60公尺，將外車道與機慢車道合併為混合車道，並繪設直右分流式指向線。（2）檢視無號誌路口且支道未劃設「停」或「讓」，截至112年5月底已完成改善 321 處。（3）111年度路老師推廣交通安全教育計畫，深入社區辦理 16 場次宣導。（4）於10處易肇事路口設置科技執法。（5）透過廣播、臉書、警察局官網及各種活動場合，持續加強宣導正確交通用路觀念。
3.	有關108至110年發生A1及A2交通事故之無號誌路口改善計畫，除蘇澳鎮公所3處路口係位於自來水管線汰換工區及慶安段自辦市地重劃工區內，將於工程完工後辦理改善外，其餘路口縣政府及12鄉（鎮、市）公所已於期限內改善完成。
4.	縣政府於112年3月提報公路總局初步月票規劃方案，並於5月提送補助經費需求計畫書至公路總局，同時辦理月票方案所需相關工作，預計於6月底前完成。推動公共運輸月票方案初期民眾使用習慣將逐漸改變，預期公共運輸量與111年相比，112年可成長1％、113年3％、114年5％，在通勤方案執行期間將持續行銷宣傳，以避免未達年度目標而遭折減補助款。

        第2則 
        標題：媽祖文化節執行情形
        內容：
(一)審核情形
縣政府考量嚴重特殊傳染性肺炎（COVID－19）疫情停辦110年蘭陽媽祖文化節活動，在疫情日漸趨緩下，為延續108年北臺灣媽祖文化節及109年蘭陽媽祖文化節，賡續於111年9月16至18日舉辦111年蘭陽媽祖文化節活動，計畫經費1,000萬元，實際支用數1,066萬餘元（66萬餘元係勻支同工作計畫經費）。經查計畫執行情形，核有：
1.原計畫規劃委託辦理成果報告及效益評估，惟實際僅辦理滿意度調查，仍未訂定量化績效衡量指標，難以衡量投入資源達成之活動預期效益及實際執行成效。
2.委託辦理調查雖有9成受訪民眾表示滿意，惟仍有6成受訪民眾未消費購買商品及住宿，對於促進活絡經濟效益之達成有待釐清，且尚無研議由民間主辦之評估作為。
3.媽祖文化節海巡賞鯨船運送服務採購案，部分承保項目之保險金額與契約規定有間。
(二)機關改善情形
1.該府委託學術單位辦理活動滿意度調查結果，已建立經濟產業、文化傳承交流、結合推動觀光、參與年齡年輕化及持續擴大參與宮廟量能等基礎資料，並建議將滿意度調查制度化，建立資料庫納為自我評鑑機制，將上開建議作為未來精進活動效益與成效之參考作為。
2.因疫情尚未全面解封，影響國人出遊意願；112年蘭陽媽祖文化節預算總經費450萬元，縣政府已逐漸轉型為由主祀宮廟或民間主辦，將成為行政協助角色，讓民間力量發揮最大效能。
3.爾後將納入自辦海巡運送服務檢討改善，就市面保險公司提供之理賠方式選擇最佳方案，並明定採購契約條款，確實執行違約罰則。

        第3則 
        標題：少子女化對策計畫推動情形
        內容：
(一)審核情形
縣政府為配合我國少子女化對策計畫（107年－113年），於近3年度（109至111年度）分別編列經費7,835萬餘元、8,373萬餘元及1億376萬餘元，執行結果，實際數分別為6,893萬餘元、7,572萬餘元及1億32萬餘元，經查該府推動少子女化對策計畫執行情形，核有：
1.	近3年度公共化幼兒園招收人數及占比呈現逐年下降趨勢。
2.	0至2歲（未滿）嬰幼兒家外送托覆蓋率低於少子女化對策計畫績效指標，且公共托育機構設置不均。
3.	部分僱用員工100人以上之雇主未依規定提供哺（集）乳室、托兒設施或措施，且申請補助家數偏低。
(二)機關改善情形
1.	經分析有更多家長選擇以幼兒園可提供服務時間及教保服務內容作為評估標的，未來策進作為包括：逐年下修師生比，加強教保服務人員專業知能及優質服務，並研商提高課後留園開辦率之可行方案，以提高家長選讀公共化教保服務之意願，減少家長育兒負擔。
2.	將研謀提升公共化及準公共化托育服務量能，及補助家長托育費用，減輕家長育兒負擔，並持續滾動檢討提升家外送托率；另積極協助三星鄉及頭城鎮等公所申請布建公共托育設施經費補助，提升不同區位之服務量能，並視原鄉地區之托育型態，布建親子館，提供近便、整合性高之社區支持資源服務，優化托育服務。
3.	因宜蘭縣產業型態多為製造業，員工多已過生養育時期，故托兒需求低，致企業申請補助家數不多，且考量財政資源有限，有關推動職場新形態托育模式，將藉由各項活動加強宣導，積極輔導企業，以提升其申請意願。
 
        資料內容如下：
[{原始內容}]
提醒，請注意：
1.簡化標題，標題文字僅簡要敘述查核計畫名稱
2.內容共分為2部分，「（一）審核情形」部分要有「核有」，精簡敘述行政機關執行計畫概況及審計室審核情形，「(二)機關改善情形」部分，簡述行政機關改善成果。
3.盡量維持審計機關習慣的用語，不要改成白話文。
'''



def 轉譯資訊發布提問(原始內容): 
    return f'''在台灣，請用繁體中文回答。以下我將提供審計部臺灣省宜蘭縣審計室對於追蹤查核意見後續改善情形後，所辦理的3則資訊發布標題與架構內容給您參考。

        第1則 
        標題：宜蘭縣部分建築物公共安全及消防安全檢查作業未臻周妥，審計機關促請改善
        內容：
        宜蘭縣政府(下稱縣政府)及所屬消防局(下稱消防局)執行建築物公共安全及消防安全檢查作業，經審計部臺灣省宜蘭縣審計室查核發現，部分供公眾使用之建築物有逾期或漏未申報公共安全或消防安全設備檢查，及停歇業場所未予列管等情事，經函請檢討改善，已完成建築物(場所)申報及加強停歇業場所之列管與追蹤，並訂定統一裁罰基準，保障民眾生命財產及維護公共安全。
        審計室指出，依建築法第77條第3項規定，供公眾使用之建築物，應由建築物所有權人、使用人定期委託中央主管建築機關認可之專業機構或人員檢查簽證，其檢查簽證結果應向當地主管建築機關申報；消防法第9條第1項規定，各類場所之管理權人，應定期檢修消防安全設備；其檢修結果，應依規定期限報請場所所在地主管機關審核，場所有歇業或停業之情形者，亦同。截至111年底止，縣政府及消防局列管應申報建築物公共安全及消防安全檢查之建築物或場所，計有6,547處及11,084處。
        然而，審計室於112年2月查核發現，列管項目中逾期未完成建築物公共安全申報者16處、漏未申報建築物公共安全者有10處、漏未申報消防安全設備檢查者有4處，又對於違反上述有關建築法之規定者，尚未訂定統一裁罰基準，另消防局對於停歇業場所及其使用現況尚無列管資料，管理作業有欠周妥，審計室遂於112年3月函請縣政府及消防局檢討改善。
        審計室表示，經追蹤改善情形，縣政府及消防局已督促所有權人或管理權人等依規定辦理申報，截至112年底止，上述30處逾期或漏未申報者均已完成申報審查作業；又停歇業場所經清查後，計有253處均已列管追蹤使用情形，保障民眾生命財產及維護公共安全。另縣政府已於112年7月17日訂定發布「宜蘭縣政府處理違反建築法使用管理規定事件統一裁罰基準」，完備制度規章。

        第2則 
        標題：宜蘭縣部分土地未依實際使用情形核課地價稅，審計機關促請改善
        內容： 
        宜蘭縣政府財政稅務局(下稱財稅局)辦理地價稅稅籍清查作業，經審計部臺灣省宜蘭縣審計室查核發現，部分課徵田賦或減免地價稅土地未依實際使用情形改課或恢復課徵地價稅，或非都市計畫公共設施保留地未按一般用地稅率核課地價稅等情事，經函請檢討改善，已釐正稅籍並依法改課或補徵地價稅1,216萬餘元，以維護租稅公平。
        審計室指出，財稅局為健全稅籍、確保稅源及遏止逃漏，以達到公平課稅、增裕庫收目標，每年度訂定地價稅稅籍及使用情形清查作業實施計畫，定期於1月1日起至9月30日止辦理課徵田賦土地、特別稅率用地及減免稅地之清查作業。
        然而，審計室於109年10月運用地理資訊系統(QGIS)與內政部國土測繪中心國土利用調查成果圖進行空間套疊分析查核發現，部分課徵田賦或減免地價稅土地，作為商業、混合使用住宅、製造業、倉儲、停車場等非供農業用途使用，或都市計畫公共設施保留地未按6‰核課地價稅，非屬公共設施保留地未按一般用地稅率核課，或已取得收益之國有土地，未依規定改課或恢復課徵地價稅等，核有短(溢)徵情事，審計室遂於109年12月函請財稅局積極檢討辦理。
        審計室表示，經追蹤改善情形，截至110年1月底止，財稅局已釐正稅籍並依法改課或補徵地價稅共計747筆、金額1,216萬餘元，退還稅款28筆、金額25萬餘元，財稅局將運用QGIS等資訊技術勾稽產出異常資料，列入爾後年度地價稅稅籍清查計畫辦理，以提升清查成效，維護租稅公平。
        
        第3則 
        標題：宜蘭縣五結防潮閘門改善工程一再流標，審計機關促請改善
        內容：
        宜蘭縣政府(下稱縣政府)辦理五結防潮閘門改善工程(下稱閘門改善工程)，經審計部臺灣省宜蘭縣審計室查核發現，縣政府未確認領標廠商未參與投標之原因，致工程發包作業遲未完成，經函請檢討改善，已洽詢原因並經調整招標文件內容後順利完成發包作業，有助閘門改善工程之進行。
        審計室指出，縣政府因冬山河排水系統之五結防潮閘門使用近50年，結構老舊水密性不佳，影響防洪禦潮功能須進行改建，於107年8月委託工程顧問公司辦理規劃設計工作，嗣於110年8月11日完成細部設計審查後，同年12月7日辦理閘門改善工程發包作業，預算金額10億1,283萬餘元，工期1,050日曆天，預定113年11月底完工。
        然而，審計室於111年3月查核發現，閘門改善工程因預算單價偏低，經檢討調整後仍因無廠商參與而流標3次，審計室遂於111年6月函請縣政府檢討妥處，經追蹤結果，縣政府雖已檢討招標文件內容，並調增工程預算為12億6,209萬元，惟因未確認領標廠商未投標之原因，截至112年3月底止，閘門改善工程已連續6次流標，工程發包作業遲未完成，乃於112年5月再函請縣政府積極研謀改善。
        審計室表示，經追蹤改善情形，縣政府已責請工程顧問公司洽詢領標廠商瞭解未參與投標之原因，並據以調整招標文件內容及工程預算單價，公開招標後則積極邀請潛在廠商參與，閘門改善工程已於112年9月13日決標，決標金額12億7,752萬餘元，預計116年6月完工，以確保防洪禦潮功能。

        請將下列的資料內容，仿照上面3則資訊發布的標題與架構內容規則，寫成1則資訊發布：
        
        資料內容如下：
[{原始內容}]
提醒，請注意：
1.簡化標題，標題文字僅簡要敘述查核發現缺失，審計機關促請改善
2.內容共分為4段論述，第1段精簡敘述全貌，要有行政機關作為，「審計部臺灣省宜蘭縣審計室查核發現」及「經函請檢討改善」，機關的改善成果。第2段要有「審計室指出」，說明行政機關相關作為。第3段要有「然而，審計室查核發現」，說明行政機關缺失，審計室函請改善。第4段要有「審計室表示，經追蹤改善情形」，行政機關改善成果。
3.盡量維持審計機關習慣的用語，不要改成白話文。
'''

def 檔案內容轉譯資訊發布提問並複製剪貼簿(檔案):
    from clipboard import copy
    from naotw.winman import TEMP, where
    import os
    tmp = TEMP / 'gpt.tmp'
    pandoc = where('pandoc')[0]
    cmd = f'{pandoc} -t plain "{檔案}" -o "{tmp}"'
    os.system(cmd)
    with tmp.open(encoding='utf8') as f:
        content = f.read()
    t = 轉譯資訊發布提問(content)
    copy(t)
    
def 檔案內容轉譯議會備詢提問並複製剪貼簿(檔案):
    from clipboard import copy
    from naotw.winman import TEMP, where
    import os
    tmp = TEMP / 'gpt.tmp'
    pandoc = where('pandoc')[0]
    cmd = f'{pandoc} -t plain "{檔案}" -o "{tmp}"'
    os.system(cmd)
    with tmp.open(encoding='utf8') as f:
        content = f.read()
    t = 轉譯議會備詢提問(content)
    copy(t)
 
def 設定環境():
    from naotw.winman import 增加所有檔案右鍵選單之功能
    import sys
    pythonexe = sys.executable
    cmd = f'"{pythonexe}" -m naotw.gpt --file2news "%1"' 
    增加所有檔案右鍵選單之功能('轉譯資訊發布提問', cmd)
    cmd = f'"{pythonexe}" -m naotw.gpt --file2inquery "%1"' 
    增加所有檔案右鍵選單之功能('轉譯議會備詢提問', cmd)

if __name__ == '__main__':
    import argparse
    from pathlib import Path
    parser = argparse.ArgumentParser()
    parser.add_argument("--file2news", help="檔案內容轉譯資訊發布提問並複製剪貼簿"
                       ,required=False
                       )
    args = parser.parse_args()
    if args.file2news:
        檔案內容轉譯資訊發布提問並複製剪貼簿(args.file2news)
    else:
        設定環境()
